Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3195)

Unified Diff: chrome/common/chrome_switches.cc

Issue 21150006: Introduce --cancel-first-run and reduce the strength of --no-first-run. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: add first_run::IsFirstRunSuppressed() Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/chrome_switches.h ('k') | chrome/installer/setup/setup_main.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/chrome_switches.cc
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index ae29419d7d0b86d7cbecd6555bfedff39ddecfbf..742b66c7ca96a21deff8bf9526a5a81a433541fe 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -140,6 +140,10 @@ const char kAutomationClientChannelID[] = "automation-channel";
const char kAutomationReinitializeOnChannelError[] =
"automation-reinitialize-on-channel-error";
+// Similar to kSkipFirstRun, but also drops the First Run beacon so that first
+// run will not occur in subsequent runs either.
+const char kCancelFirstRun[] = "cancel-first-run";
+
// How often (in seconds) to check for updates. Should only be used for testing
// purposes.
const char kCheckForUpdateIntervalSec[] = "check-for-update-interval";
@@ -789,7 +793,8 @@ const char kFileDescriptorLimit[] = "file-descriptor-limit";
const char kForceAppMode[] = "force-app-mode";
// Displays the First Run experience when the browser is started, regardless of
// whether or not it's actually the First Run (this overrides kNoFirstRun).
const char kForceFirstRun[] = "force-first-run";
// Tries to load cloud policy for every signed in user, regardless of whether
@@ -961,12 +966,6 @@ const char kNoEvents[] = "no-events";
// then restart chrome without this switch again.
const char kNoExperiments[] = "no-experiments";
-// Skip First Run tasks, whether or not it's actually the First Run. Overridden
-// by kForceFirstRun.
-// Also drops the First Run beacon so that First Run will not occur in
-// subsequent runs as well.
-const char kNoFirstRun[] = "no-first-run";
cpu_(ooo_6.6-7.5) 2013/07/30 21:41:36 please check/search if documentation in chromium.o
gab 2013/07/31 00:00:51 Actually this makes me realize that a bunch of ran
gab 2013/08/01 15:14:49 ping, what do you guys think of ^^ ?
-
// Support a separate switch that enables the v8 playback extension.
// The extension causes javascript calls to Date.now() and Math.random()
// to return consistent values, such that subsequent loads of the same
@@ -1261,6 +1260,11 @@ const char kSimulateCriticalUpdate[] = "simulate-critical-update";
// Simulates that current version is outdated.
const char kSimulateOutdated[] = "simulate-outdated";
+// Skip First Run tasks, whether or not it's actually the First Run. Overridden
+// by kForceFirstRun. This doesn't prevent first run from occuring the next time
+// chrome is launched without this flag.
+const char kSkipFirstRun[] = "skip-first-run";
+
// Replaces the buffered data source for <audio> and <video> with a simplified
// resource loader that downloads the entire resource into memory.
« no previous file with comments | « chrome/common/chrome_switches.h ('k') | chrome/installer/setup/setup_main.cc » ('j') | no next file with comments »
@@ -789,7 +793,8 @@ const char kFileDescriptorLimit[] = "file-descriptor-limit";
const char kForceAppMode[] = "force-app-mode";
// Displays the First Run experience when the browser is started, regardless of
-// whether or not it's actually the First Run (this overrides kNoFirstRun).
+// whether or not it's actually the First Run (this overrides kSkipFirstRun and
+// kCancelFirstRun).
const char kForceFirstRun[] = "force-first-run";
// Tries to load cloud policy for every signed in user, regardless of whether

Powered by Google App Engine
This is Rietveld 408576698